==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/PAGEFIELD.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ELEMENTID" type="{http://schemas.datastream.net/MP_fields}CODE60_Type"/>
 *         &lt;element name="ELEMENTATTRIBUTE" type="{http://schemas.datastream.net/MP_fields}CODE1_Type"/>
 *         &lt;element name="FIELDCONTAINER" type="{http://schemas.datastream.net/MP_fields}CODE20_Type" minOccurs="0"/>
 *         &lt;element name="FIELDGROUP" type="{http://www.w3.org/2001/XMLSchema}long" minOccurs="0"/>
 *         &lt;element name="PRESENTINJSP" type="{http://schemas.datastream.net/MP_fields}CODE1_Type"/>
 *         &lt;element name="PAGEDEFAULTVALUE" type="{http://schemas.datastream.net/MP_fields}CODE1000_Type" minOccurs="0"/>
 *         &lt;element name="FILTERSTRXML" type="{http://schemas.datastream.net/MP_fields}CODE2000_Type" minOccurs="0"/>
 *         &lt;element name="USERFILTER" type="{http://schemas.datastream.net/MP_fields}CODE2000_Type" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDFIELDINFO" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "elementid",
    "elementattribute",
    "fieldcontainer",
    "fieldgroup",
    "presentinjsp",
    "pagedefaultvalue",
    "filterstrxml",
    "userfilter",
    "userdefinedfieldinfo"
})
@XmlRootElement(name = "PAGEFIELD")
public class PAGEFIELD {

    @XmlElement(name = "ELEMENTID", required = true)
    protected String elementid;
    @XmlElement(name = "ELEMENTATTRIBUTE", required = true)
    protected String elementattribute;
    @XmlElement(name = "FIELDCONTAINER")
    protected String fieldcontainer;
    @XmlElement(name = "FIELDGROUP")
    protected Long fieldgroup;
    @XmlElement(name = "PRESENTINJSP", required = true)
    protected String presentinjsp;
    @XmlElement(name = "PAGEDEFAULTVALUE")
    protected String pagedefaultvalue;
    @XmlElement(name = "FILTERSTRXML")
    protected String filterstrxml;
    @XmlElement(name = "USERFILTER")
    protected String userfilter;
    @XmlElement(name = "USERDEFINEDFIELDINFO")
    protected USERDEFINEDFIELDINFO userdefinedfieldinfo;

    /**
     * Obtient la valeur de la propriété elementid.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getELEMENTID() {
        return elementid;
    }

    /**
     * Définit la valeur de la propriété elementid.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setELEMENTID(String value) {
        this.elementid = value;
    }

    /**
     * Obtient la valeur de la propriété elementattribute.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getELEMENTATTRIBUTE() {
        return elementattribute;
    }

    /**
     * Définit la valeur de la propriété elementattribute.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setELEMENTATTRIBUTE(String value) {
        this.elementattribute = value;
    }

    /**
     * Obtient la valeur de la propriété fieldcontainer.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFIELDCONTAINER() {
        return fieldcontainer;
    }

    /**
     * Définit la valeur de la propriété fieldcontainer.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFIELDCONTAINER(String value) {
        this.fieldcontainer = value;
    }

    /**
     * Obtient la valeur de la propriété fieldgroup.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getFIELDGROUP() {
        return fieldgroup;
    }

    /**
     * Définit la valeur de la propriété fieldgroup.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setFIELDGROUP(Long value) {
        this.fieldgroup = value;
    }

    /**
     * Obtient la valeur de la propriété presentinjsp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRESENTINJSP() {
        return presentinjsp;
    }

    /**
     * Définit la valeur de la propriété presentinjsp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRESENTINJSP(String value) {
        this.presentinjsp = value;
    }

    /**
     * Obtient la valeur de la propriété pagedefaultvalue.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPAGEDEFAULTVALUE() {
        return pagedefaultvalue;
    }

    /**
     * Définit la valeur de la propriété pagedefaultvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPAGEDEFAULTVALUE(String value) {
        this.pagedefaultvalue = value;
    }

    /**
     * Obtient la valeur de la propriété filterstrxml.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFILTERSTRXML() {
        return filterstrxml;
    }

    /**
     * Définit la valeur de la propriété filterstrxml.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFILTERSTRXML(String value) {
        this.filterstrxml = value;
    }

    /**
     * Obtient la valeur de la propriété userfilter.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERFILTER() {
        return userfilter;
    }

    /**
     * Définit la valeur de la propriété userfilter.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERFILTER(String value) {
        this.userfilter = value;
    }

    /**
     * Obtient la valeur de la propriété userdefinedfieldinfo.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDFIELDINFO }
     *     
     */
    public USERDEFINEDFIELDINFO getUSERDEFINEDFIELDINFO() {
        return userdefinedfieldinfo;
    }

    /**
     * Définit la valeur de la propriété userdefinedfieldinfo.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDFIELDINFO }
     *     
     */
    public void setUSERDEFINEDFIELDINFO(USERDEFINEDFIELDINFO value) {
        this.userdefinedfieldinfo = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/PAGEFIELD.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ELEMENTID" type="{http://schemas.datastream.net/MP_fields}CODE60_Type"/>
 *         &lt;element name="ELEMENTATTRIBUTE" type="{http://schemas.datastream.net/MP_fields}CODE1_Type"/>
 *         &lt;element name="FIELDCONTAINER" type="{http://schemas.datastream.net/MP_fields}CODE20_Type" minOccurs="0"/>
 *         &lt;element name="FIELDGROUP" type="{http://www.w3.org/2001/XMLSchema}long" minOccurs="0"/>
 *         &lt;element name="PRESENTINJSP" type="{http://schemas.datastream.net/MP_fields}CODE1_Type"/>
 *         &lt;element name="PAGEDEFAULTVALUE" type="{http://schemas.datastream.net/MP_fields}CODE1000_Type" minOccurs="0"/>
 *         &lt;element name="FILTERSTRXML" type="{http://schemas.datastream.net/MP_fields}CODE2000_Type" minOccurs="0"/>
 *         &lt;element name="USERFILTER" type="{http://schemas.datastream.net/MP_fields}CODE2000_Type" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDFIELDINFO" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "elementid",
    "elementattribute",
    "fieldcontainer",
    "fieldgroup",
    "presentinjsp",
    "pagedefaultvalue",
    "filterstrxml",
    "userfilter",
    "userdefinedfieldinfo"
})
@XmlRootElement(name = "PAGEFIELD")
public class PAGEFIELD {

    @XmlElement(name = "ELEMENTID", required = true)
    protected String elementid;
    @XmlElement(name = "ELEMENTATTRIBUTE", required = true)
    protected String elementattribute;
    @XmlElement(name = "FIELDCONTAINER")
    protected String fieldcontainer;
    @XmlElement(name = "FIELDGROUP")
    protected Long fieldgroup;
    @XmlElement(name = "PRESENTINJSP", required = true)
    protected String presentinjsp;
    @XmlElement(name = "PAGEDEFAULTVALUE")
    protected String pagedefaultvalue;
    @XmlElement(name = "FILTERSTRXML")
    protected String filterstrxml;
    @XmlElement(name = "USERFILTER")
    protected String userfilter;
    @XmlElement(name = "USERDEFINEDFIELDINFO")
    protected USERDEFINEDFIELDINFO userdefinedfieldinfo;

    /**
     * Gets the value of the elementid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getELEMENTID() {
        return elementid;
    }

    /**
     * Sets the value of the elementid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setELEMENTID(String value) {
        this.elementid = value;
    }

    /**
     * Gets the value of the elementattribute property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getELEMENTATTRIBUTE() {
        return elementattribute;
    }

    /**
     * Sets the value of the elementattribute property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setELEMENTATTRIBUTE(String value) {
        this.elementattribute = value;
    }

    /**
     * Gets the value of the fieldcontainer property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFIELDCONTAINER() {
        return fieldcontainer;
    }

    /**
     * Sets the value of the fieldcontainer property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFIELDCONTAINER(String value) {
        this.fieldcontainer = value;
    }

    /**
     * Gets the value of the fieldgroup property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getFIELDGROUP() {
        return fieldgroup;
    }

    /**
     * Sets the value of the fieldgroup property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setFIELDGROUP(Long value) {
        this.fieldgroup = value;
    }

    /**
     * Gets the value of the presentinjsp property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRESENTINJSP() {
        return presentinjsp;
    }

    /**
     * Sets the value of the presentinjsp property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRESENTINJSP(String value) {
        this.presentinjsp = value;
    }

    /**
     * Gets the value of the pagedefaultvalue property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPAGEDEFAULTVALUE() {
        return pagedefaultvalue;
    }

    /**
     * Sets the value of the pagedefaultvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPAGEDEFAULTVALUE(String value) {
        this.pagedefaultvalue = value;
    }

    /**
     * Gets the value of the filterstrxml property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFILTERSTRXML() {
        return filterstrxml;
    }

    /**
     * Sets the value of the filterstrxml property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFILTERSTRXML(String value) {
        this.filterstrxml = value;
    }

    /**
     * Gets the value of the userfilter property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERFILTER() {
        return userfilter;
    }

    /**
     * Sets the value of the userfilter property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERFILTER(String value) {
        this.userfilter = value;
    }

    /**
     * Gets the value of the userdefinedfieldinfo property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDFIELDINFO }
     *     
     */
    public USERDEFINEDFIELDINFO getUSERDEFINEDFIELDINFO() {
        return userdefinedfieldinfo;
    }

    /**
     * Sets the value of the userdefinedfieldinfo property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDFIELDINFO }
     *     
     */
    public void setUSERDEFINEDFIELDINFO(USERDEFINEDFIELDINFO value) {
        this.userdefinedfieldinfo = value;
    }

}
